.. elasticsearch quiery builder documentation master file, created by
   sphinx-quickstart on Thu Mar 16 11:54:35 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to elasticsearch quiery builder's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
